@@ -44,9 +44,13 @@ typedef struct chimera_key_list {
 
 CHIMERA_SEM chimera_sw_lock,task_lock;
 CHIMERA_KEY_LIST * chimera_key_list;
+void
+chimera_loop();
+
 
 CHIMERA_SW_HASH * chimera_hash[SW_HASH_SIZE];
 int chimera_init_flag;
+int chimera_post_event_flag;
 
 void
 chimera_sw_init()
@@ -54,6 +58,7 @@ chimera_sw_init()
 	task_lock = chimera_new_lock();
 	chimera_sw_lock = chimera_new_lock();
 	chimera_init_flag = 1;
+	create_task((void(*)(TKEY))chimera_loop,0,5);
 }
 
 int ws_test;
@@ -143,7 +148,9 @@ chimera_post_event()
 {
 	if ( chimera_key_list == 0 )
 		return;
-	PostEvent(keyUp,1);
+	if ( chimera_post_event_flag == 0 )
+		PostEvent(keyUp,1);
+	chimera_post_event_flag = 1;
 }
 
 void
@@ -156,7 +163,11 @@ CHIMERA_KEY_LIST * k;
 	k->key = key;
 	k->next = chimera_key_list;
 	chimera_key_list = k;
-	PostEvent(keyUp,1);
+
+	if ( chimera_post_event_flag == 0 )
+		PostEvent(keyUp,1);
+	chimera_post_event_flag = 1;
+
 	if ( lock_flag )
 		chimera_unlock_task(task_lock,"normal_wakeup_task",__FILE__,__LINE__);
 }
@@ -261,6 +272,8 @@ CALL_THIS_LST * lst;
 		if ( ret < 0 )
 			return -1;
 		break;
+	case CHIMERA_N_APP:
+		chimera_post_event_flag = 0;
 	default:
 		if ( call_this.head )
 			return -1;
@@ -315,6 +328,14 @@ end:
 	return ret;
 }
 
+void
+chimera_loop()
+{
+	for ( ; ; ) {
+		sleep_sec(1);
+		normal_wakeup_routine(CHIMERA_N_NONE,0);
+	}
+}
 
 
 
