@@ -297,7 +297,7 @@ typedef void* VTreeNodeInfo;
 
 #define RGB8_MAX	255
 
-int ms_do(int (*func)(), void * arg,char str[]);
+int ms_do(int (*func)(void *), void * arg,char str[]);
 #define V_SERIALIZED_EXEC(func, arg)  ms_do((int(*)(void*))func, (void*)arg, (char*)"V_SERIALIZED_EXEC")
 
 enum VdataType {
