@@ -54,7 +54,6 @@ XL_INTERPRETER * xli;
 	setup_i(xli);
 }
 
-
 void
 init_main()
 {
@@ -116,17 +115,25 @@ _main(int argc,char ** argv)
 	}
 	if ( strcmp(argv[1],"v") == 0 ) {
 // OK
+		start_alloc_time_list();
+
 		tick_start_lock();
 
 		init_sg();
 
 		view_init(argc,argv);
-
 // unlock NG
 
 		init_ex_language(gblisp_top_env1);
 // unlock NG
-
+/*
+{
+char * a;
+	a = d_alloc(100);
+	d_f_ree(a);
+	a[10] = 0;
+}
+*/
 		vobject_init_gb(&argc, &argv);
 		init_vobj_function_gb();
 // unlock NG 		
@@ -209,10 +216,13 @@ void VgbFlame_save_preference_wpm();
 	xli = new_xl_interpreter();
 	xli->a_type = XLA_SELF;
 	setup_i(xli);
+	
+	s_shutdown_stream(STT_NET);
 
 	VgbFlame_save_preference_wpm();
 	rcache_stop();
 	disable_rcache();
+	
 	close_all_matrix();
 	quit_flag = 2;
 	vobject_quit();
