@@ -330,6 +330,7 @@ cnt = 0;
 			bw->load_max > 0 ; 
 			m = R_NEXT(MAP*,&m->h) ) {
 cnt ++;
+
 		g = 0;
 		if ( m->src_url.resource ) {
 			len = l_strlen(m->src_url.resource);
@@ -432,6 +433,7 @@ LOAD_RESOURCE_WORK * wp;
 				m->map_file = 0;
 				goto err;
 			}
+			insert_parent_list(r,m->map_file);
 			ret = 1;
 			this_coord = 1;
 		}
@@ -464,6 +466,7 @@ LOAD_RESOURCE_WORK * wp;
 
 			if ( m->src == 0 )
 				goto err;
+			insert_parent_list(r,m->src);
 			ret = 1;
 			this_coord = 1;
 			if ( m->src->h.notes )
@@ -946,8 +949,10 @@ char * e_param;
 int
 browse_coord(RESOURCE * r,BROWSE_WORK * bw)
 {
-LOAD_RESOURCE_WORK * w;
-int ret;
+LOAD_RESOURCE_WORK * w, * wp;
+int ret,_ret;
+int pf;
+LOAD_RESOURCE_SERVICE_CODE * cl;
 	if ( bw->type == BWT_ROUTE ) {
 		er_panic("BROWSE");
 		return 0 ;
@@ -956,6 +961,23 @@ int ret;
 		w = load_children_map(r,bw);
 		load_resource_list(w,Q_PRI_OBJ,1);
 		ret = browse_children_map(bw->ses,r,bw,w);
+		pf = 0;
+		for ( wp = w ; wp ; wp = wp->req_next )
+			if ( wp->err == LRWE_ERROR_PERMISSION ) {
+				copy_insert_lw_service_code_flag_set(r,wp->auth_service_code);
+				wf_auth_information(r);
+				pf = 1;
+			}
+		if ( pf == 0 ) {
+			cl = 0;
+			_ret = copy_delete_lw_service_code(&cl,r);
+			free_lw_service_code(cl,0);
+			if ( _ret ) {
+				wf_auth_information(r);
+				wf_insert_dirty_rect(r,&r->h.minrect,WFF_LUSTER_DIRTY|WFF_POLY_DIRTY,10,10);
+			}
+		}
+
 		free_lrw_req_next(w);
 		if ( ret )
 			do_initial(r);
@@ -1206,10 +1228,11 @@ rect_cnt ++;
 		}
 
 		unlock_task(res_lock,"draw_coordinate");
-		if ( wf_active_check_2(gf,dw->wfid) < 0 )
-{ss_printf("FREE=RETURN-COORDINATE\n");
+		if ( wf_active_check_2(gf,dw->wfid) < 0 ) {
+ss_printf("FREE=RETURN-COORDINATE\n");
+			lock_task(res_lock);
 			break;
-}
+		}
 		lock_task(res_lock);
 
 	}
