@@ -81,7 +81,7 @@ next:
 /*
 	create_task(pixel_req_task,0,PRI_FETCH);
 */
-	new_tick(pixel_gc_tick,1,0);
+	new_tick((void(*)(int))pixel_gc_tick,1,0);
 	
 	init_old_matrix();
 }
@@ -91,6 +91,7 @@ next:
 void
 gv_new_luster_option(RESOURCE * r,int r64_level)
 {
+ss_printf("new_luster_option\n");
 	switch ( r->pr64.type ) {
 	case 'P':
 	case 'G':
@@ -345,6 +346,11 @@ int xx,yy;
 INTEGER64 mx,my;
 int clr;
 	m = r->h.mtx;
+	if ( m == 0 ) {
+		gv_new_luster_option(r,0);
+		if ( r->h.mtx == 0 )
+			return 0;
+	}
 	clr = 0;
 	if ( cache->n ) {
 		if ( cache->level == lev &&
@@ -657,8 +663,11 @@ int int_divide;
 		return;
 	if ( get_mov_flag(gf,dw->wfid) != 0 )
 		return;
-	if ( r->h.mtx == 0 )
-		return;
+	if ( r->h.mtx == 0 ) {
+		gv_new_luster_option(r,0);
+		if ( r->h.mtx == 0 )
+			return;
+	}
 	mtx = r->h.mtx;
 
 	divide = 1;
