@@ -168,7 +168,7 @@ GB_POINT * pt_list;
 REAL1 * pt_reso;
 int w,h;
 MAP_HISTORY * mh;
-WIN_FLAME * td, * _wf;
+WIN_FLAME * _wf;
 SURP_SET surp;
 int id;
 int ci_ret;
@@ -251,9 +251,11 @@ unsigned long * target;
 		wf_unlock(gf);
 		return -2;
 	}
+/*
 	for ( td = wf->next ; td ; td = td->next )
 		if ( td->draw->c.ov->h.filter == ov_default )
 			break;
+*/
 	width = wf->small_rct.br.x - wf->small_rct.tl.x;
 	for ( yy = r->tl.y ; yy < r->br.y ; yy ++ ) {
 		yy_index = (yy - wf->small_rct.tl.y) * width;
@@ -844,7 +846,7 @@ int ret;
 				goto no_data;
 			else if ( x < src_rct.tl.x )
 				goto no_data;
-			else if ( x >= src_rct.br.y )
+			else if ( x >= src_rct.br.x )
 				goto no_data;
 			*d_ptr = src[(x-src_rct.tl.x) + (y-src_rct.tl.y)*width];
 			continue;
