@@ -23,25 +23,25 @@
 #include	"favt64.h"
 #include	"long_char.h"
 
-typedef struct dtree_node64 {
+typedef struct dtree64_node {
 	L_CHAR			ch;
-	unsigned int		tree;
-	unsigned int		data;
-} DTREE_NODE64;
+	U_INTEGER64		tree;
+	U_INTEGER64		data;
+} DTREE64_NODE;
 
-typedef struct dtree_trace_work64 {
-	PDB64 * 			p;
+typedef struct dtree64_trace_work {
+	PDB64 * 		p;
 	int 			(*func)();
 	void *			w;
 	int 			(*trace)();
 	L_CHAR *		target;
-} DTREE_TRACE_WORK64;
+} DTREE64_TRACE_WORK;
 
-void dtree_endian64();
-FAVT_ROOT64 * alloc_dtree64(PDB64 * p,int type);
-unsigned int search_dtree64(int * sizep,FAVT_ROOT64 * r,L_CHAR * str,int perfect_flag);
-int dtree_trace_from_small64(FAVT_ROOT64 * r,int (*func)(),void * work);
-int dtree_trace_from_large64(FAVT_ROOT64 * r,int (*func)(),void * work);
+void dtree64_endian();
+FAVT64_ROOT * alloc64_dtree(PDB64 * p,int type);
+U_INTEGER64 search_dtree64(int * errp,int * sizep,FAVT64_ROOT * r,L_CHAR * str,int perfect_flag);
+int dtree64_trace_from_small(int * errp,FAVT64_ROOT * r,int (*func)(),void * work);
+int dtree64_trace_from_large(int * errp,FAVT64_ROOT * r,int (*func)(),void * work);
 
 #endif
 
