@@ -97,6 +97,12 @@ typedef struct gv_resource_list {
 	struct gv_resource_list *	next;
 } GV_RESOURCE_LIST;
 
+typedef struct gv_auth_info {
+	WF_ID				id;
+	RESOURCE *			r;
+	struct gbview_flame *		gf;
+} GV_AUTH_INFO;
+
 
 typedef struct gbview_flame {
 	int		id;
@@ -182,6 +188,7 @@ typedef struct gbview_flame {
 #define ET_CHANGE_BASE	5	/* 0 */
 #define ET_LOCK_BASE	6	/* 0 */
 #define ET_STATUS	7	/* 0 */
+#define ET_AUTH		8	/* GV_AUTH_INFO * */
 
 	void *		event_user_arg;
 
