@@ -108,7 +108,8 @@ typedef struct matrix_token {
 	XL_SEXP *			cal_target;
 	void				(*func)();
 	void 				(*aboat_func)();
-	void *				aobat_work;
+	void *				aboat_work;
+	int				aboat_status;
 	MATRIX_SEXP *			env;
 
 	int				loop_no;
