@@ -306,5 +306,36 @@ PDB64 * open_pdb64(char * filename,int oflags,int mode,int flags);
 void close_pdb64(PDB64 *);
 
 
+/*******************************/
+/*
+	Associate Memory
+*/
+/*******************************/
+
+typedef struct assoc64_index {
+	INTEGER64	fofs;
+	short		type;
+#define AIT_INTEGER	1
+#define AIT_STRING	2
+	short		name;
+} ASSOC64_INDEX;
+
+typedef struct pn64_assoc_header {
+	PN64_HEADER	h;
+	ASSOC64_INDEX	ix[1];
+} PN64_ASSOC_HEADER;
+
+#define PN64_ASSOC_HEADER_S(x)	((int)(&(((PN64_ASSOC_HEADER*)0)->ix[x])))
+
+typedef struct pn64_assoc_data {
+	PN64_HEADER	h;
+	char		data[1];
+} PN64_ASSOC_DATA;
+
+#define PN64_ASSOC_DATA_S(x)	((int)(&(((PN64_ASSOC_DATA*)0)->data[x])))
+
+
+
+
 #endif
 
