@@ -329,7 +329,10 @@ typedef struct note {
 	L_CHAR *		url;
 } NOTE;
 
-
+typedef struct res_parent_list {
+	struct res_parent_list *	next;
+	union resource *		parent;
+} RES_PARENT_LIST;
 
 typedef struct res_header {
 	union resource * entry_next;
@@ -348,23 +351,25 @@ typedef struct res_header {
 
 #define RF_CACHE		0x00000010
 #define RF_UNCACHE		0x00000020
-#define RF_ERROR		0x00000040
+#define RF_CACHE_CLEAR		0x00000040
+#define RF_ERROR		0x00000080
+#define RF_PERMISSION		0x00000100
 
-#define RF_COMPLETE		0x00000100
-#define RF_LOAD_EXTEND		0x00000200
-#define RF_LOAD_EXTEND_PROC	0x00000400
+#define RF_COMPLETE		0x00000200
+#define RF_LOAD_EXTEND		0x00000400
+#define RF_LOAD_EXTEND_PROC	0x00000800
 
-#define RF_FORCE_LOAD_CHI	0x00000800
-#define RF_INHERIT		0x00001000
-#define RF_EDIT			0x00002000
-#define RF_RES_DIRTY		0x00004000
+#define RF_FORCE_LOAD_CHI	0x00001000
+#define RF_INHERIT		0x00002000
+#define RF_EDIT			0x00004000
+#define RF_RES_DIRTY		0x00008000
 
 #define RF_INDICATE		0x03000000
 #define RF_I_OFF		0x00000000
 #define RF_I_ON			0x01000000
 #define RF_I_AUTO		0x02000000
 
-#define RF_PARAM_FLAGS		(RF_UNCACHE|RF_FORCE_LOAD_CHI|RF_INHERIT|RF_EDIT)
+#define RF_PARAM_FLAGS		(RF_UNCACHE|RF_CACHE_CLEAR|RF_FORCE_LOAD_CHI|RF_INHERIT|RF_EDIT)
 	unsigned int	modify;
 	GB_RECT		minrect;
 	GB_RECT		edit_minrect;
@@ -386,12 +391,15 @@ typedef struct res_header {
 	COORDINATE_UNIT cu;
 
 	XL_SEXP *	data;
+	struct load_resource_service_code *	auth_service_code;
+	RES_PARENT_LIST *	p_list;
 
 	int		cache_file_id;
 
 	int		draw_code;
 #ifdef USE_MATRIX
 	MATRIX *	mtx;
+	unsigned	mtx_loading:1;
 	int		visu_channel;
 #endif
 } RES_HEADER;
@@ -813,6 +821,11 @@ typedef struct load_resource_option {
 	int		flags;
 } LOAD_RESOURCE_OPTION;
 
+typedef struct load_resource_service_code {
+	struct load_resource_service_code *	next;
+	L_CHAR *				service;
+	AUTH_TABLE *				type;
+} LOAD_RESOURCE_SERVICE_CODE;
 
 typedef struct load_resource_work {
 
@@ -851,6 +864,7 @@ typedef struct load_resource_work {
 #define LRWE_ERROR_URL		(-9)
 #define LRWE_ERROR_GET1		(-10)
 #define LRWE_ERROR_GET2		(-11)
+#define LRWE_ERROR_PERMISSION	(-12)
 #define LRWE_HANDLING	1
 #define LRWE_NOTUSE	2
 #define LRWE_COMPLETE	3
@@ -874,6 +888,7 @@ typedef struct load_resource_work {
 	unsigned int	insert_time;
 	unsigned int	remote_time;
 	unsigned int	int_remote_time;
+	LOAD_RESOURCE_SERVICE_CODE *	auth_service_code;
 
 	struct load_resource_work *	first_next;
 
@@ -1278,6 +1293,20 @@ int
 map_history_length(MAP_HISTORY * mh);
 BIB_LIST *
 gv_get_biblist(L_CHAR * url);
+void
+insert_lw_service_code(LOAD_RESOURCE_SERVICE_CODE ** scp,XL_SEXP * s,int);
+void
+copy_insert_lw_service_code(LOAD_RESOURCE_SERVICE_CODE ** dest,LOAD_RESOURCE_SERVICE_CODE * src,int if_lock);
+void
+free_lw_service_code(LOAD_RESOURCE_SERVICE_CODE * sc,int if_lock);
+int
+copy_delete_lw_service_code(LOAD_RESOURCE_SERVICE_CODE ** dest,RESOURCE * r);
+void
+copy_insert_lw_service_code_flag_set(RESOURCE * r,LOAD_RESOURCE_SERVICE_CODE * src);
+RESOURCE **
+insert_lw_service_code_flag_set_get_parent(RESOURCE * r,XL_SEXP * s);
+void
+insert_parent_list(RESOURCE * parent,RESOURCE * child);
 
 
 /* Channels of old matrix */
