@@ -45,6 +45,13 @@ extern "C" {
 #define VMT_WARP_INSERT_MODE	VMT_CONV(-10104)
 #define VMT_WARP_INSERT_MODE_STR VMT_STR(-10104)
 
+#define VMT_COPY_WARP_POINT	VMT_CONV(-10105)
+#define VMT_COPY_WARP_POINT_STR	VMT_STR(-10105)
+
+#define VMT_SET_IWP		VMT_CONV(-10106)
+#define VMT_SET_IWP_STR		VMT_STR(-10106)
+
+
 #define VMT_WARP_ENTRY_MIN_ABS	VMT_CONV(-11000)
 
 #define VMT_WARP_ENTRY_MAX_ABS	VMT_CONV(-13000)
@@ -63,10 +70,11 @@ extern "C" {
 #define VSF_FLAME_INDICATE_TREE_INFO	(1<<11)
 #define VSF_FLAME_INDICATE_TREE_BASE	(1<<12)
 #define VSF_FLAME_INDICATE_TREE_WEB	(1<<13)
-#define VSF_FLAME_OATTRIBUTE_HANDLER	(1<<14)
-#define VSF_FLAME_SELECT_MODE		(1<<15)
-#define VSF_FLAME_RELATED_FLAME		(1<<16)
-#define VSF_FLAME_FOCUS			(1<<17)
+#define VSF_FLAME_INDICATE_TREE_AUTH	(1<<14)
+#define VSF_FLAME_OATTRIBUTE_HANDLER	(1<<15)
+#define VSF_FLAME_SELECT_MODE		(1<<16)
+#define VSF_FLAME_RELATED_FLAME		(1<<17)
+#define VSF_FLAME_FOCUS			(1<<18)
 
 typedef struct _VgbFlameStatus {
 	int			style;
@@ -96,6 +104,8 @@ typedef struct _VgbFlameStatus {
 	VRect			indicate_tree_base_elr[5];
 	VImage *		indicate_tree_web;
 	VRect			indicate_tree_web_elr[3];
+	VImage *		indicate_tree_auth;
+	VRect			indicate_tree_auth_elr[3];
 
 	V_CALLBACK		(oattribute_handler);
 	void *			oattribute_handler_arg;
@@ -137,6 +147,7 @@ typedef struct _VgbFlameStatus {
 #define VSF_FLAME_C_LAYERS			(1<<9)
 #define VSF_FLAME_C_PP_RADIUS			(1<<10)
 #define VSF_FLAME_C_TARGET			(1<<11)
+#define VSF_FLAME_C_USE_IWP			(1<<12)
 
 typedef struct _VgbFlameLayers {
 	struct _VgbFlameLayers *	next;
@@ -165,6 +176,7 @@ typedef struct _VgbFlameCoordinateStatus {
 
 	REAL1		pp_radius;
 	L_CHAR *	target;
+	unsigned	use_iwp:1;
 } VgbFlameCoordinateStatus;
 
 
@@ -239,13 +251,17 @@ typedef struct tv_shadow {
 	int		flags;
 	RESOURCE * 	r;
 	VStaticText *	main_text;
+	VStaticText *	copyright_text;
 	VStaticText *	chi_text;
 	L_CHAR *	homepage;
+	L_CHAR *	copyright;
 	VexDraw *	eye;
 	VexDraw *	info;
 	VexDraw *	base;
 	VexDraw *	web;
+	VexDraw *	auth;
 	VBackColorView *	main_bc;
+	VBackColorView *	copyright_bc;
 	VBackColorView *	chi_bc;
 } TV_SHADOW;
 
@@ -279,6 +295,7 @@ typedef struct flame_work {
 	VImage *			tree_view_info[2];
 	VImage *			tree_view_base[5];
 	VImage *			tree_view_web[3];
+	VImage *			tree_view_auth[3];
 	
 	V_CALLBACK			(oattribute_handler);
 	void *				oattribute_handler_arg;
@@ -469,18 +486,25 @@ class VgbFlameStandard : public VgbFlame
 	virtual void _base_handler(VObject*);
 	virtual void _info_handler(VObject*);
 	virtual void _web_handler(VObject*);
+	virtual void _auth_handler(VObject*);
 	virtual int _flame_focus_handler(int edit_type,int len,VBackColorView ** bcl);
 	virtual void _flame_focus_command_status();
 	virtual void _flame_focus_obey_command(int type);
 	void _set_warp_point_menu();
+	void _copy_warp_point();
 	void _warp_point(WARP_POINT*);
 	void _initial_menu_set(VWindow * win);
 	void _final_menu_set(VWindow * win);
 	void _initial_focus_set(VWindow * win);
 	void _final_focus_set(VWindow * win);
 	void _warp_point_callback_mode(int);
-	static WARP_POINT_MENU * get_wpm();
+	static WARP_POINT_MENU * get_wpm(int type);
+#define GET_WPM_WARPMENU	1
+#define GET_WPM_IWP		2
 	static void set_wpm(WARP_POINT_MENU*);
+	void _set_iwp();
+
+	void _set_DrawAuth(RESOURCE * r);
 
 	// XL gc processing if using XL_SEXP in VObject
 	//	defined by each VMacro Object
@@ -544,7 +568,7 @@ xx_free_wpm(WARP_POINT_MENU* m,char * f,int ln);
 extern "C" WARP_POINT_MENU*
 copy_wpm(WARP_POINT_MENU* m);
 extern "C" int
-VgbFlame_load_wpm(L_CHAR * filename,int flag);
+VgbFlame_load_wpm(L_CHAR * filename,int type,int flag);
 L_CHAR * 
 get_title_string(FLAME_SWITCH * sw,L_CHAR * url,int type);
 #define GTF_URL		0x00000001
@@ -554,5 +578,32 @@ print_wpm(char*,WARP_POINT_MENU * w);
 extern "C" int
 VgbFlame_set_wpm(WARP_POINT_MENU * wpm,int flag);
 
+// ==================================================
+// CLIPBOARD FOR TRACKBACK
+
+
+extern VIM VIM_VdataTRACKBACK;
+
+
+class VdataTRACKBACK : public VdataXL
+{
+  public:
+
+	VdataTRACKBACK(const L_CHAR *str,int * erp=0,bool valid=1);
+	VdataTRACKBACK(const char *str,int * erp=0,bool valid=1);
+	VdataTRACKBACK(const XL_SEXP * s,int * erp=0,bool valid=1);
+	VdataTRACKBACK(Vdata * d,int * erp=0,bool valid=1);
+	virtual ~VdataTRACKBACK();
+
+	static bool clipboard_available(bool lock_flag=1);
+	static VdataTRACKBACK * new_from_clipboard();
+
+	virtual char * get_VdataString(int * erp=0);
+	virtual L_CHAR * get_VdataLString(int * erp=0);
+	virtual XL_SEXP * get_VdataXL(int * erp=0);
+	virtual VdataXL * get_VdataTRACKBACK(int * erp=0);
+  protected:
+};
+
 
 #endif
