@@ -33,6 +33,7 @@
 #endif
 
 #define LOG_MEM_LIST_LEN	20
+#define FREE_RAG		10000000
 
 void memory_debug_task(); 
 
@@ -63,15 +64,22 @@ int md_flag;
 
 
 typedef struct mem_header {
+	struct mem_header *	time_next;
 	MEM_LIST *		mlp;
 	int			size;
 
 	char *			last_free_file;
 	int			last_free_line;
-
+	char *			first_alloc_file;
+	int			first_alloc_line;
 } MEM_HEADER;
 
 
+MEM_HEADER * memory_time_list_head;
+MEM_HEADER * memory_time_list_tail;
+INTEGER64 memory_time_list_size;
+
+
 int lm_trace(AVT_NODE * a,AVT_NODE ** ret);
 int lm_log_output(AVT_NODE * a,int * cnt);
 
@@ -88,9 +96,12 @@ int mem_free_info_len;
 MEM_PURGE_TBL *	mpt_root;
 static INTEGER64 total_mem_size;
 
+int enabled_time_list;
+
 void ind_tick();
 void list_tick();
 
+
 void
 init_d_alloc()
 {
@@ -99,10 +110,67 @@ init_d_alloc()
 	if ( md_flag == 1 )
 		er_panic("init_d_alloc");
 	new_tick((void(*)(int))list_tick,30,0);
-	create_task(memory_debug_task,PRI_FETCH,0);
+	create_task((void(*)(TKEY))memory_debug_task,PRI_FETCH,0);
 #endif
 }
 
+#define CHECK_CHAR	0x79
+
+void
+start_alloc_time_list()
+{
+#ifndef DONT_USE_LOCK
+	LOCK;
+	enabled_time_list = 1;
+	UNLOCK;
+#endif
+}
+
+void
+insert_time_list(MEM_HEADER * mh)
+{
+#ifndef DONT_USE_LOCK
+
+char * ptr;
+int i;
+	ptr = (char*)(mh+1);
+	for ( i = mh->size ; i > 0 ; i -- )
+		*ptr++ = CHECK_CHAR;
+	mh->time_next = 0;
+	if ( memory_time_list_tail == 0 ) {
+		memory_time_list_tail = memory_time_list_head = mh;
+	}
+	else {
+		memory_time_list_tail->time_next = mh;
+		memory_time_list_tail = mh;
+	}
+	memory_time_list_size += mh->size;
+	for ( ; memory_time_list_size > FREE_RAG ; ) {
+		if ( memory_time_list_head == 0 )
+			er_panic("insert_time_list");
+		mh = memory_time_list_head;
+		memory_time_list_head = mh->time_next;
+		if ( memory_time_list_head == 0 )
+			memory_time_list_tail = 0;
+		memory_time_list_size -= mh->size;
+		ptr = (char*)(mh+1);
+		for ( i = mh->size ; i > 0 ; i -- , ptr ++ ) {
+			if ( *ptr != CHECK_CHAR ) {
+				ptr = malloc(10000);
+				sprintf(ptr,"MEMORY PANIC\nALLOC POINT %s %i\nFREE POINT %s %i",
+					mh->first_alloc_file,
+					mh->first_alloc_line,
+					mh->last_free_file,
+					mh->last_free_line);
+				er_panic(ptr);
+			}
+		}
+		free(mh);
+	}
+#endif
+}
+
+
 void
 _new_mem_hash()
 {
@@ -174,6 +242,8 @@ void * ret;
 
 		mh->last_free_file = 0;
 		mh->last_free_line = 0;
+		mh->first_alloc_file = file;
+		mh->first_alloc_line = line;
 
 		ml->size += size;
 		ret = mh+1;
@@ -304,13 +374,16 @@ int s;
 	s = mh->size;
 	ml->size -= mh->size;
 //printf("d_f_ree %p\n",mh);
-	{
+	if ( enabled_time_list == 0 ) {
 /*
 		int e=GetLastError();
 		int en=errno;
 */
 		free(mh);
 	}
+	else {
+		insert_time_list(mh);
+	}
 
 //printf("d_f_ree %p END\n",mh);
 	total_mem_size -= s + sizeof(*mh);
