@@ -322,7 +322,7 @@ PDB64 * p;
 	size = n->h.size = nn->data_len + sizeof(PN64_FAVT_NODE);
 	change_endian_favt64_node(n);
 	u_lseek64(p->fid,h->fofs,SEEK_SET);
-	fa_write64_header(p->fid,n,size);
+	fa_write64_header(p,n,size);
 	d_f_ree(n);
 	return 0;
 }
@@ -340,7 +340,7 @@ PN64_FAVT_ROOT r;
 	r.h.size = sizeof(r);
 	change_endian_favt64_root(&r);
 	u_lseek64(h->p->fid,h->fofs,SEEK_SET);
-	fa_write64_header(h->p->fid,&r,sizeof(r));
+	fa_write64_header(h->p,&r,sizeof(r));
 	return 0;
 }
 
