@@ -364,6 +364,7 @@ _unlock_save(MATRIX_NODE*n)
 	n->save_lock = 0;
 	n->dirty_file_time = 0;
 	wakeup_task((int)n);
+	wakeup_task((int)n->matrix);
 }
 
 
@@ -614,6 +615,7 @@ _matrix_node_channel_unlock(MATRIX_NODE * n,int flags)
 			_set_dirty_file(n);
 		n->ch_lock_tid = 0;
 	}
+	wakeup_task((int)n->matrix);
 	wakeup_task((int)n);
 	
 }
@@ -763,6 +765,33 @@ sync_matrix(MATRIX * m)
 	unlock_task(matrix_lock,"sync_matrix");
 }
 
+void
+close_aboat_func(int d)
+{
+MATRIX_TOKEN * t;
+	t = (MATRIX_TOKEN*)d;
+	if ( t->aboat_func )
+		(*t->aboat_func)(t);
+	lock_task(matrix_lock);
+	if ( t->aboat_status < 0 ) {
+		t->aboat_status ++;
+		if ( t->aboat_status == 0 )
+			d_f_ree(t);
+	}
+	else {
+		t->aboat_status --;
+	}
+	unlock_task(matrix_lock,"close_aboat_func");
+}
+
+void
+aboat_status_countup(MATRIX_TOKEN * t)
+{
+	if ( t->aboat_status < 0 )
+		t->aboat_status --;
+	else	t->aboat_status ++;
+}
+
 void
 _close_matrix(MATRIX * m)
 {
@@ -772,7 +801,7 @@ MATRIX_SEXP * d;
 MATRIX_NODE * n, * n2;
 MATRIX_TOKEN * t;
 int ret_id;
-//int pri;
+int pri;
 int retry_f;
 	retry_f = 0;
 	if ( m->mode == MM_CLOSE )
@@ -794,7 +823,8 @@ retry:
 		for ( t = m->wait_token ; t ; t = t->next ) {
 			if ( t->aboat_func == 0 )
 				continue;
-			(t->aboat_func)(t);
+			aboat_status_countup(t);
+			new_tick((void(*)(int))close_aboat_func,0,(int)t);
 		}
 		sleep_task((int)m,matrix_lock);
 		lock_task(matrix_lock);
@@ -814,8 +844,11 @@ ss_printf("close_matirx ret_id = %i %i\n",ret_id,matrix_que.total_cnt);
 				if ( n->dirty_file_time && n->status == MS_OK )
 					_matrix_trigger_access(n,MI_SAVE_TP,0);
 				t = n->process_token;
-				if ( t && t->aboat_func )
-					(*t->aboat_func)(t);
+				if ( t && t->aboat_func ) {
+					aboat_status_countup(t);
+					new_tick((void(*)(int))close_aboat_func,0,(int)t);
+//					(*t->aboat_func)(t);
+				}
 /*
 				sleep_task((int)n,matrix_lock);
 				lock_task(matrix_lock);
@@ -829,15 +862,13 @@ ss_printf("close_matirx ret_id = %i %i\n",ret_id,matrix_que.total_cnt);
 		retry_f = 1;
 	}
 	if ( retry_f ) {
-		unlock_task(matrix_lock,"");
-		sleep_sec(1);
-/*
+		new_timeout((int)m,1);
 		pri = get_pri(0);
 		change_pri(0,PRI_RCACHE);
+		sleep_task((int)m,matrix_lock);
 		change_pri(0,pri);
-*/
 		lock_task(matrix_lock);
-	
+		del_timeout((int)m);
 		goto retry;
 	}
 	for ( i = 0 ; i < m->p.channel_nos ; i ++ ) {
@@ -1851,7 +1882,11 @@ ss_printf("EXIT %x:%i =\n",t,t->access_target_id);
 	n = t->process_node;
 	n->process_token = 0;
 	wakeup_task((int)n);
-	d_f_ree(t);
+	if ( t->aboat_status > 0 )
+		t->aboat_status = -t->aboat_status;
+	if ( t->aboat_status == 0 ) {
+		d_f_ree(t);
+	}
 	m->token_cnt --;
 	if ( m->token_cnt < 0 )
 		er_panic("token_cnt");
@@ -1948,6 +1983,7 @@ MATRIX_LIST ** lp,* lst;
 				break;
 			}
 	}
+	wakeup_task((int)n->matrix);
 	wakeup_task((int)n);
 }
 
