@@ -386,7 +386,7 @@ int ret;
 int
 write_mx_cache_vector(MX_CACHE_PARAM * _p)
 {
-int i;
+int i,j;
 int * ofs;
 //MATRIX_DATA_TYPE * tp;
 int el_size;
@@ -430,7 +430,6 @@ MX_CACHE_PARAM p;
 	}
 
 
-//ss_printf("====\n");
 	dc = mxc_alloc(c,sizeof(INTEGER64)*(m->p.dim+1));
 	for ( i = 0 ; i < m->p.dim ; i ++ ) {
 		if ( p.dc[i+1] >= m->pixel_size[i] )
@@ -482,9 +481,19 @@ ss_printf("BB %x %x %x %x\n",
 (buffer_ptr + el_size*offset_ix)[2],
 (buffer_ptr + el_size*offset_ix)[3]);
 */
-				memcpy(p1,
-					buffer_ptr + el_size*offset_ix,
-					el_size*slen);
+				if ( p.vector_valid ) {
+					for ( j = 0 ; j < slen ; j ++  ) {
+						if ( p.vector_valid[offset_ix+j] == 0 )
+							continue;
+						memcpy(((char*)p1) + j*el_size,
+							buffer_ptr + el_size*(offset_ix+j),
+							el_size);
+					}
+				}
+				else
+					memcpy(p1,
+						buffer_ptr + el_size*offset_ix,
+						el_size*slen);
 			}
 			else {
 				goto err;
