@@ -43,6 +43,7 @@ XL_SEXP *
 insert_src(NETLIST_VERTEX * v,XL_SEXP * el,XL_SEXP * x,XL_SEXP * y,XL_SEXP * s,NETLIST_WORK * w)
 {
 NETLIST_SRC * src,** sp;
+int e_type;
 	if ( get_type(el) != XLT_STRING )
 		goto invalid_header_name;
 
@@ -56,6 +57,8 @@ NETLIST_SRC * src,** sp;
 	src->fileheader = ll_copy_str(w->fileheader);
 	src->floating = 0;
 	switch ( get_type(x) ) {
+	case XLT_ERROR:
+		return x;
 	case XLT_FLOAT:
 		src->ptr.x = x->floating.data;
 		break;
@@ -69,10 +72,16 @@ NETLIST_SRC * src,** sp;
 		}
 		else	sscanf(n_string(std_cm,x->string.data),"%f",&src->ptr.x);
 		break;
+	case XLT_NULL:
+		src->ptr.x = 0;
+		break;
 	default:
+		e_type = get_type(x);
 		goto invalid_point;
 	}
 	switch ( get_type(y) ) {
+	case XLT_ERROR:
+		return y;
 	case XLT_FLOAT:
 		src->ptr.y = y->floating.data;
 		break;
@@ -87,7 +96,11 @@ NETLIST_SRC * src,** sp;
 		}
 		else	sscanf(n_string(std_cm,y->string.data),"%f",&src->ptr.y);
 		break;
+	case XLT_NULL:
+		src->ptr.y = 0;
+		break;
 	default:
+		e_type = get_type(y);
 		goto invalid_point;
 	}
 	src->next = 0;
@@ -112,7 +125,7 @@ invalid_point:
 		l_string(std_cm,"Netlist"),
 		List(n_get_string("type missmatch point coordinate (floating or integer)"),
 			n_get_string("data line No. is"),
-			get_integer(el->h.line,0),-1));
+			get_integer(el->h.line,0),get_integer(e_type,0),-1));
 }
 
 
@@ -147,10 +160,16 @@ ss_printf("INSERT VERTEX\n");
 	for ( ; get_type(lin) == XLT_PAIR ; ) {
 		name = car(lin);
 		lin = cdr(lin);
-		x = car(lin);
-		lin = cdr(lin);
-		y = car(lin);
-		lin = cdr(lin);
+		if ( get_type(lin) == XLT_PAIR ) {
+			x = car(lin);
+			lin = cdr(lin);
+			y = car(lin);
+			lin = cdr(lin);
+		}
+		else {
+			x = n_get_string("0");
+			y = n_get_string("0");
+		}
 		ret = insert_src(v,name,x,y,s,w);
 		if ( get_type(ret) == XLT_ERROR )
 			return ret;
