@@ -693,7 +693,7 @@ int length, result;
 	}
 	create_task((void(*)(TKEY))XLoHTTP_task,(int)ret->xoh.info,PRI_WRITE_BUF);
 	lock_task(stream_lock);
-	_s_open(ret,O_RDWR);
+	_s_open(ret,O_RDWR,STT_OTHERS);
 	unlock_task(stream_lock,"s_connect_XLoHTTP");
 
 	return ret;
