@@ -304,7 +304,21 @@ _s_printf(STREAM *s,int * erp, char * fmt, va_list p){
 			for ( ; ptr > 0 ; ) {
 				ss = ptr;
 			retry:
+				lock_task(stream_lock);
+				if ( s->h.write_abort_type ) {
+					s->h.write_tid = get_tid();
+					s->h.write_in_time = get_xltime();
+				}
+				unlock_task(stream_lock,"s_write");
+
 				er = (*tbl->write)(s,pp,ss);
+
+
+				lock_task(stream_lock);
+				s->h.write_tid = 0;
+				s->h.write_in_time = 0;
+				unlock_task(stream_lock,"s_write(2)");
+
 				if ( er < 0 ) {
 					if ( errno == ESYS_AGAIN ) {
 						ss = ss/2;
