@@ -560,7 +560,7 @@ RESOLVE_REQUEST_T n;
 	wakeup_task((int)&resolve_que_head);
 	if ( resolve_launch == 0 ) {
 		resolve_launch = 1;
-		create_task(resolve_thread,PRI_FETCH,0);
+		create_task((void(*)(TKEY))resolve_thread,PRI_FETCH,0);
 	}
 	else wakeup_task((int)&resolve_tid);
 	for ( ; n.ok == 0 ; ) {
@@ -581,6 +581,7 @@ RESOLVE_QUEUE rq;
 /*
 ss_printf("r_get_hostbyaddr :: %x\n",a.d.v4);
 */
+
 	lock_task(resolve_lock2);
 retry2:
 	ret = _search_host_entry_byaddr(a);
@@ -657,6 +658,7 @@ RESOLVE_QUEUE rq;
 /*
 ss_printf("r_get_hostbyname :: %s\n",name);
 */
+
 	lock_task(resolve_lock2);
 retry2:
 	ret = _search_host_entry_byname(name);
