@@ -1,4 +1,4 @@
-/* ver.B.b08(BLAZE) */
+/* ver.B.b16.06(BLAZE) */
 
 
 #include "version.h"
@@ -7,9 +7,9 @@
 VERSION ap_version = {
 	"AP.code",
 	"pdbstatus",
-	"(C) 2000-2005 Hirohisa Mori",
-	"ver.B.b08(BLAZE)",
-	2006,4,26,
+	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
+	"ver.B.b16.06(BLAZE)",
+	2007,6,26,
 	0,
 	"pdb (progressive DB) status viewer ",
 };
