@@ -1,4 +1,4 @@
-/* ver.B.b16.04(BLAZE) */
+/* ver.B.b16.07(BLAZE) */
 
 
 #include "version.h"
@@ -8,9 +8,9 @@ VERSION ap_version = {
 	"AP.code",
 	"xlsv",
 	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
-	"ver.B.b16.04(BLAZE)",
-	2007,6,4,
+	"ver.B.b16.07(BLAZE)",
+	2007,6,27,
 	0,
-	"XL server agent ? gbs/doc/xml/man/html/ja-cosmos",
+	"XL server agent ",
 };
 
