@@ -60,6 +60,8 @@ vsat_VgbFlameStandard_translator(VObject* obj, void* arg);
 
 XL_SEXP *
 vobj_load_warp_point_menu(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf);
+XL_SEXP *
+gb_trackback(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf);
 
 void
 init_vobj_VgbFlameStandard(XLISP_ENV *env)
@@ -68,6 +70,11 @@ init_vobj_VgbFlameStandard(XLISP_ENV *env)
 		get_func_prim((XL_SEXP*(*)())vobj_VgbFlameStandard,FO_NORMAL,0,1,1));
 	set_env(env,l_string(std_cm,"VgbFlameStandardLoadWPM"),
 		get_func_prim((XL_SEXP*(*)())vobj_load_warp_point_menu,FO_APPLICATIVE,0,1,2));
+	set_env(gblisp_top_env0,l_string(std_cm,"trackback"),
+		get_func_prim((XL_SEXP*(*)())gb_trackback,FO_NORMAL,0,2,2));
+
+
+
 	set_env(env,l_string(std_cm,"VMT-WARP"),
 		n_get_string(VMT_WARP_STR));
 	set_env(env,l_string(std_cm,"VMT-ADD-WARP"),
@@ -78,6 +85,12 @@ init_vobj_VgbFlameStandard(XLISP_ENV *env)
 		n_get_string(VMT_WARP_REPLACE_MODE_STR));
 	set_env(env,l_string(std_cm,"VMT-WARP-INSERT-MODE"),
 		n_get_string(VMT_WARP_INSERT_MODE_STR));
+
+	set_env(env,l_string(std_cm,"VMT-COPY-WARP-POINT"),
+		n_get_string(VMT_COPY_WARP_POINT_STR));
+
+	set_env(env,l_string(std_cm,"VMT-SET-IWP"),
+		n_get_string(VMT_SET_IWP_STR));
 }
 
 char * _get_point_from_char(REAL1 * ret,char * str)
@@ -159,6 +172,11 @@ L_CHAR * d;
 		sts->target = ll_copy_str(d);
 		(*flags) |= VSF_FLAME_C_TARGET;
 	}
+	d = get_sf_attribute(sf,l_string(std_cm,"flame.crd.UseIWP"));
+	if ( d ) {
+		sts->use_iwp = atoi(n_string(std_cm,d));
+		(*flags) |= VSF_FLAME_C_USE_IWP;
+	}
 	return 0;
 }
 
@@ -440,6 +458,11 @@ L_CHAR * d;
 		sts->indicate_tree_web_elr[1]
 			= get_elr(n_string(std_cm,d),sts->indicate_tree_web);
 	}
+	d = get_sf_attribute(sf,l_string(std_cm,"flame.IndicateTreeWeb.elr2"));
+	if ( d ) {
+		sts->indicate_tree_web_elr[3]
+			= get_elr(n_string(std_cm,d),sts->indicate_tree_web);
+	}
 	d = get_sf_attribute(sf,l_string(std_cm,"flame.IndicateTreeWeb.elr"));
 	if ( d ) {
 		get_elr_ary(
@@ -447,6 +470,38 @@ L_CHAR * d;
 			n_string(std_cm,d),sts->indicate_tree_web);
 	}
 
+	d = get_sf_attribute(sf,l_string(std_cm,"flame.IndicateTreeAuth.raw"));
+	if ( d )  {
+		sts->indicate_tree_auth = 
+			get_image_from_lchar(&_ret,env,arg->h.file->name,d);
+		if ( get_type(_ret) == XLT_ERROR ) {
+			ret = "flame.IndicateTreeAuth.raw";
+			goto err;
+		}
+		(*flags) |= VSF_FLAME_INDICATE_TREE_AUTH;
+	}
+	d = get_sf_attribute(sf,l_string(std_cm,"flame.IndicateTreeAuth.elr0"));
+	if ( d ) {
+		sts->indicate_tree_auth_elr[0]
+			= get_elr(n_string(std_cm,d),sts->indicate_tree_auth);
+	}
+	d = get_sf_attribute(sf,l_string(std_cm,"flame.IndicateTreeAuth.elr1"));
+	if ( d ) {
+		sts->indicate_tree_auth_elr[1]
+			= get_elr(n_string(std_cm,d),sts->indicate_tree_auth);
+	}
+	d = get_sf_attribute(sf,l_string(std_cm,"flame.IndicateTreeAuth.elr2"));
+	if ( d ) {
+		sts->indicate_tree_auth_elr[3]
+			= get_elr(n_string(std_cm,d),sts->indicate_tree_auth);
+	}
+	d = get_sf_attribute(sf,l_string(std_cm,"flame.IndicateTreeAuth.elr"));
+	if ( d ) {
+		get_elr_ary(
+			&sts->indicate_tree_auth_elr[0],
+			n_string(std_cm,d),sts->indicate_tree_auth);
+	}
+
 	d = get_sf_attribute(sf,l_string(std_cm,"flame.OAttributeHandler"));
 	if ( d ) {
 	VSysArgTranslator * vsat;
@@ -842,8 +897,16 @@ vobj_load_warp_point_menu(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD
 XL_SEXP * f;
 L_CHAR * f_path;
 char file[100];
-	sprintf(file,"%swarppoint.xml",get_preference_path());
-	if ( VgbFlame_load_wpm(l_string(&utf8_cm,file),0) == 0 )
+L_CHAR * type;
+L_CHAR * preference_filename;
+int _type;
+	type = get_sf_attribute(sf,l_string(std_cm,"type"));
+	if ( type == 0 )
+		_type = 1;
+	else	_type = atoi(n_string(std_cm,type));
+	preference_filename = get_sf_attribute(sf,l_string(std_cm,"preference"));
+	sprintf(file,"%s%s",get_preference_path(),n_string(std_cm,preference_filename));
+	if ( VgbFlame_load_wpm(l_string(&utf8_cm,file),_type,0) == 0 )
 		return 0;
 	if ( list_length(s) == 1 )
 		goto cannot_open;
@@ -851,7 +914,7 @@ char file[100];
 	if ( get_type(f) != XLT_STRING )
 		goto type_missmatch;
 	f_path = get_absolute_path(f->string.data);
-	if ( VgbFlame_load_wpm(f_path,1) < 0 )
+	if ( VgbFlame_load_wpm(f_path,_type,1) < 0 )
 		goto cannot_open;
 	return 0;
 type_missmatch:
@@ -870,6 +933,74 @@ cannot_open:
 		n_get_string("preference and the given file can not be opened"));
 }
 
+XL_SEXP *
+gb_trackback(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
+{
+XL_SEXP * inp,*sym;
+XL_SEXP * ret;
+RADAR_CACHE * rc_ptr;
+WARP_POINT * wp;
+char * err;
+
+ss_printf("TRACKBACK\n");
+	inp = get_el(s,1);
+	switch ( get_type(inp) ) {
+	case XLT_STRING:
+		rc_ptr = get_sf_rc_ptr(sf);
+		if ( rc_trackback(&ret,rc_ptr,inp->string.data) < 0 ) {
+			if ( get_type(ret) == XLT_ERROR )
+				return ret;
+			return get_error(
+				s->h.file,
+				s->h.line,
+				XLE_PROTO_OPEN_FILE,
+				l_string(std_cm,"trackback"),
+				List(n_get_string("cannot open a window for trackback"),
+					ret,-1));
+		}
+		break;
+	case XLT_PAIR:
+		sym = car(inp);
+		if ( get_type(sym) != XLT_SYMBOL )
+			goto type_missmatch;
+		if ( l_strcmp(sym->symbol.data,l_string(std_cm,"warp-point")) == 0 ) {
+			wp = sexp2wp(inp);
+			if ( wp == 0 ) {
+				err = "trackback warp-point type missmatch";
+				goto type_missmatch;
+			}
+			rc_ptr = get_sf_rc_ptr(sf);
+			if ( rc_ptr == 0 ) {
+				return get_error(
+					s->h.file,
+					s->h.line,
+					XLE_PROTO_OPEN_FILE,
+					l_string(std_cm,"trackback"),
+					List(n_get_string("cannot open a window for trackback"),
+						-1));
+			}
+			rc_warp(rc_ptr,WT_WARP_POINT,0,0,0,0,0,wp,1);
+			free_warp_point(wp);
+		}
+		else {
+			err = "invalid symbol in trackback";
+			goto type_missmatch;
+		}
+		break;
+	default:
+		err = "trackback URL type missmatch";
+		goto type_missmatch;
+	}
+	return 0;
+type_missmatch:
+	return get_error(
+		s->h.file,
+		s->h.line,
+		XLE_SEMANTICS_TYPE_MISSMATCH,
+		l_string(std_cm,"trackback"),
+		n_get_string(err));
+}
+
 
 } // extern "C"
 
