@@ -252,8 +252,8 @@ init_interpreter()
 	xllisp_site = nl_copy_str(std_cm,&site_name[0]);
 */
 
-	create_task(delay_thread,0,PRI_XL_RELAY);
-	create_task(xli_tick_task,0,PRI_XL_TICK);
+	create_task((void(*)(TKEY))delay_thread,0,PRI_XL_RELAY);
+	create_task((void(*)(TKEY))xli_tick_task,0,PRI_XL_TICK);
 
 	init_http_agent(); 
 
@@ -1080,15 +1080,15 @@ int pri;
 
 	switch ( xli->a_type ) {
 	case XLA_ACCEPT:
-		create_task(_accept_thread,(int)xli,PRI_XL_ACCEPT);
+		create_task((void(*)(TKEY))_accept_thread,(int)xli,PRI_XL_ACCEPT);
 		break;
 	case XLA_SELF:
 		xli->front_thread = __new_xli_thread(xli);
 		break;
 	default:
-		create_task(_front_thread,(int)xli,PRI_XL_FRONT);
+		create_task((void(*)(TKEY))_front_thread,(int)xli,PRI_XL_FRONT);
 		if ( xli->thread_mode == TM_2 )
-			create_task(_relay_thread,(int)xli,PRI_XL_RELAY);
+			create_task((void(*)(TKEY))_relay_thread,(int)xli,PRI_XL_RELAY);
 		break;
 	}
 
@@ -1540,6 +1540,7 @@ STREAM * pip;
 unsigned int next_interval,invoke_time;
 char ch;
 int opm,cop;
+int key_cnt;
 
 if ( _accept_tid == 0 ) {
 _accept_tid = malloc(sizeof(int)*1000);
@@ -1548,7 +1549,7 @@ _accept_ptr = 0;
 _accept_tid[_accept_ptr++] = get_tid();
 _accept_ptr = _accept_ptr % 1000;
 
-
+	key_cnt = 0;
 	xli = (XL_INTERPRETER*)GET_TKEY(k);
 	for ( ; ; ) {
 
@@ -1570,8 +1571,12 @@ _accept_ptr = _accept_ptr % 1000;
 			unlock_task(xli_lock,"_accept_thread");
 			if ( xli->flags & XIF_BREAK )
 				break;
+			if ( key_cnt >= 2 )
+				break;
+			key_cnt ++;
 			continue;
 		}
+		key_cnt = 0;
 
 		create_task(_accept_thread,(int)xli,PRI_XL_ACCEPT);
 
@@ -2461,7 +2466,7 @@ XL_INTERPRETER * xli;
 		unlock_task(xli_lock,"delay_thread");
 
 		if ( w.result == CDT_WAIT_ERR ) {
-			create_task(delay_thread,0,PRI_XL_RELAY);
+			create_task((void(*)(TKEY))delay_thread,0,PRI_XL_RELAY);
 			get_type(n->ret);
 		}
 		_reply(n->xli,n->line,n->ret);
