@@ -207,7 +207,7 @@ init_log(XLISP_ENV * env0,XLISP_ENV * env1)
 	setup_value(env0,log_level_msg,LOG_MAX_LEVEL);
 	setup_value(env0,log_layer,LOG_LAYER_MAX);
 
-	create_task(log_queue_task1,0,PRI_LOG);
+	create_task((void(*)(TKEY))log_queue_task1,0,PRI_LOG);
 
 //	new_tick(llpl_check,2,0);
 }
