@@ -993,7 +993,7 @@ retry:
 			break;
 		}
 		retry_cnt --;
-		if ( retry_cnt > 0 ) {
+		if ( retry_cnt > 0 && (shutdown_stream_flags & STT_NET) == 0 ) {
 			sleep_sec(2);
 			goto retry;
 		}
